local cql = ClassicQuestLog

cql.options.defaults = { -- default settings
    ShowTooltips = true,
    ShowResizeGrip = false,
    ShowLevels = false,
    LockWindow = false,
    ShowFromObjectiveTracker = true,
    UseCustomScale = false,
    CustomScale = 100,
    TempScale = 100, -- for slider control before "Set Scale" is clicked
    DontOverrideBind = false,
    ShowMinimapButton = false,
}

--[[ savedvars ]]

ClassicQuestLogSettings = {} -- the savedvar

function cql.options:Initialize()
    ClassicQuestLogSettings = ClassicQuestLogSettings or {}
    for k,v in pairs(cql.options.defaults) do
        if cql.options:Get(k)==nil then
            cql.options:Set(k,v)
        end
    end
    cql.options.content.version:SetText(format("Version %s",GetAddOnMetadata("Classic Quest Log","Version")))
    cql.options.content.UseCustomScale.ScaleSlider:SetValue(cql.options:Get("CustomScale"))
    cql:SetScale(cql.options:Get("UseCustomScale") and cql.options:Get("CustomScale")/100 or 1)
end

-- use this to get a setting
function cql.options:Get(setting)
    return ClassicQuestLogSettings[setting]
end

-- use this to set a setting
function cql.options:Set(setting,value)
    ClassicQuestLogSettings[setting] = value
end

--[[ ui ]]

function cql.options:ToggleOptions()
    if cql.mode=="options" then
        cql:SetMode("detail")
        PlaySound(SOUNDKIT.IG_QUEST_LOG_CLOSE)
    else
        cql:SetMode("options")
        PlaySound(SOUNDKIT.IG_QUEST_LOG_OPEN)
    end
end

function cql.options:OptionOnClick()
    local isChecked = self:GetChecked() and true
    PlaySound(isChecked and SOUNDKIT.IG_MAINMENU_OPTION_CHECKBOX_ON or SOUNDKIT.IG_MAINMENU_OPTION_CHECKBOX_OFF)
    cql.options:Set(self:GetParent().optVar,isChecked)
    cql.log:Update()
    cql.resizeGrip:SetShown(cql.options:Get("ShowResizeGrip"))
    if self:GetParent().optVar=="UseCustomScale" then
        if not isChecked then
            cql.options.content.UseCustomScale.ScaleSlider:SetValue(cql.options:Get("CustomScale"))
        end
        cql:SetScale(cql.options:Get("UseCustomScale") and cql.options:Get("CustomScale")/100 or 1)
        cql.options:UpdateScaleControl()
    end
    if self:GetParent().optVar=="DontOverrideBind" then
        cql:UpdateBindingOverride()
    end
    if self:GetParent().optVar=="ShowMinimapButton" then
        ClassicQuestLogMinimapButton:SetShown(isChecked)
    end
end

-- update the checks on the options to reflect current settings
function cql.options:Update()
    for k,v in pairs(cql.options.defaults) do
        if cql.options.content[k] then
            cql.options.content[k].check:SetChecked(cql.options:Get(k))
        end
    end
    cql.options:Set("TempScale",cql.options:Get("CustomScale"))
    cql.options.content.UseCustomScale.ScaleSlider:SetValue(cql.options:Get("CustomScale"))
end

-- when the scale slider changes, only change the temp value and not the actual scale
-- (can't change as slider changes due to scale making the slider potentially leaving the mouse, making it weird)
function cql.options:ScaleSliderOnValueChanged(value)
    cql.options:Set("TempScale",value)
    --cql.options:Set("CustomScale",value)
    cql.options:UpdateScaleControl()
end

-- when the "Set Scale" button is clicked to set/save the new scale value
-- (can't change as slider changes due to scale making the slider potentially leaving the mouse, making it weird)
function cql.options:CustomScaleSetButton()
    cql.options:Set("CustomScale",cql.options:Get("TempScale"))
    cql:SetScale(cql.options:Get("UseCustomScale") and cql.options:Get("CustomScale")/100 or 1)
    cql.options:UpdateScaleControl()
end

-- updates appearance of slider and things such as Set Scale button showing only if temp scale is different than actual
function cql.options:UpdateScaleControl()
    local useScale = cql.options:Get("UseCustomScale")
    local color = useScale and "\124cffffffff" or "\124cff808080"
    local checkButton = cql.options.content.UseCustomScale
    local slider = checkButton.ScaleSlider
    local value = cql.options:Get("TempScale")
    checkButton.text:SetText(format("Use Custom Scale: %s%d%%",color,value))
    slider:SetEnabled(useScale)
    slider:SetAlpha(useScale and 1 or 0.75)
    checkButton.SetButton:SetShown(value and value~=cql.options:Get("CustomScale"))
end

